pub enum VoteType {
SingleChoice,
MultiChoice {
choice_type: MultiChoiceType,
min_voter_options: u8,
max_voter_options: u8,
max_winning_options: u8,
},
}Expand description
Proposal vote type
Variants
SingleChoice
Single choice vote with mutually exclusive choices In the SingeChoice mode there can ever be a single winner If multiple options score the same highest vote then the Proposal is not resolved and considered as Failed. Note: Yes/No vote is a single choice (Yes) vote with the deny option (No)
MultiChoice
Multiple options can be selected with up to max_voter_options per voter and with up to max_winning_options of successful options Ex. voters are given 5 options, can choose up to 3 (max_voter_options) and only 1 (max_winning_options) option can win and be executed
Fields

choice_type: MultiChoiceTypeType of MultiChoice

min_voter_options: u8The min number of options a voter must choose
Note: In the current version the limit is not supported and not enforced and must always be set to 1